<?php

namespace Drupal\commerce_swiss_post\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class ConfigForm.
 */
class SwissPostSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'commerce_swiss_post.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'commerce_swiss_post_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('commerce_swiss_post.settings');

    $form['api_host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Host'),
      '#default_value' => $config->get('api_host'),
      '#required' => TRUE
    ];
    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID'),
      '#default_value' => $config->get('client_id'),
      '#required' => TRUE
    ];
    $form['client_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client Secret Key'),
      '#default_value' => $config->get('client_secret'),
      '#required' => TRUE
    ];
    $form['franking_license'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Franking License'),
      '#default_value' => $config->get('franking_license'),
      '#required' => TRUE
    ];
    $form['label_layout'] = [
      '#type' => 'select',
      '#title' => $this->t('Label Layout'),
      '#options' => ['a5' => 'A5', 'a6' => 'A6', 'a7' => 'A7'],
      '#default_value' => $config->get('label_layout'),
      '#required' => TRUE
    ];
    $form['print_preview'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Print Preview'),
      '#description' => $this->t('Enables the print preview mode that will create "SPECIMEN" example labels instead of barcodes, for testing'),
      '#default_value' => $config->get('print_preview'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('commerce_swiss_post.settings')
      ->set('api_host', $form_state->getValue('api_host'))
      ->set('client_id', $form_state->getValue('client_id'))
      ->set('client_secret', $form_state->getValue('client_secret'))
      ->set('franking_license', $form_state->getValue('franking_license'))
      ->set('label_layout', $form_state->getValue('label_layout'))
      ->set('print_preview', $form_state->getValue('print_preview'))
      ->save();
  }

}
